package com.dxfeed.acs.sample;

import com.devexperts.rmi.RMIEndpoint;
import com.dxfeed.acs.CandleService;
import com.dxfeed.event.candle.Candle;
import com.dxfeed.event.candle.CandleSymbol;

import java.util.Collection;

/**
 * Sample class to demonstrate requesting candles via {@link CandleService}.
 */
public class SampleCandleServiceClient {

    private SampleCandleServiceClient() {}

    public static void main(String[] args) {
        if (args.length < 1) {
            System.out.println("Usage: 'java -cp acs-api\\lib\\* com.dxfeed.acs.sample.SampleCandleServiceClient <address>'");
            System.out.println("	<address> - chart server RMI address");
            System.exit(0);
        }
        String address = args[0];
        RMIEndpoint endpoint = RMIEndpoint.createEndpoint(RMIEndpoint.Side.CLIENT);
        endpoint.connect(address);
        CandleService candleService = endpoint.getClient().getProxy(CandleService.class);
        CandleSymbol candleSymbol = CandleSymbol.valueOf("AAPL{=0.25pr}");
        int candleCount = 20;
        Collection<Candle> lastCandles = candleService.getLastCandles(candleSymbol, candleCount);
        System.out.printf("Received %d candles: %s%n", lastCandles.size(), lastCandles);
        endpoint.close();
    }
}
